@@ -23,6 +23,10 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/gohugoio/hugo/common/maps"
+
+	"github.com/gohugoio/hugo/hugofs/files"
+
 	"github.com/bep/gitmap"
 
 	"github.com/gohugoio/hugo/helpers"
@@ -119,31 +123,66 @@ func (p *pageState) MarshalJSON() ([]byte, error) {
 	return page.MarshalPageToJSON(p)
 }
 
-func (p *pageState) Pages() page.Pages {
-	p.pagesInit.Do(func() {
-		if p.pages != nil {
-			return
-		}
+func (p *pageState) getPages() page.Pages {
+	b := p.bucket
+	if b == nil {
+		return nil
+	}
+	return b.getPages()
+}
 
+func (p *pageState) getPagesAndSections() page.Pages {
+	b := p.bucket
+	if b == nil {
+		return nil
+	}
+	return b.getPagesAndSections()
+}
+
+// TODO(bep) cm add a test
+func (p *pageState) RegularPages() page.Pages {
+	p.regularPagesInit.Do(func() {
 		var pages page.Pages
 
 		switch p.Kind() {
 		case page.KindPage:
-		case page.KindHome:
-			pages = p.s.RegularPages()
+		case page.KindSection, page.KindHome, page.KindTaxonomyTerm:
+			pages = p.getPages()
 		case page.KindTaxonomy:
-			termInfo := p.getTaxonomyNodeInfo()
-			taxonomy := p.s.Taxonomies[termInfo.plural].Get(termInfo.termKey)
-			pages = taxonomy.Pages()
-		case page.KindTaxonomyTerm:
-			plural := p.getTaxonomyNodeInfo().plural
-			// A list of all page.KindTaxonomy pages with matching plural
-			for _, p := range p.s.findPagesByKind(page.KindTaxonomy) {
-				if p.SectionsEntries()[0] == plural {
+			all := p.Pages()
+			for _, p := range all {
+				if p.IsPage() {
 					pages = append(pages, p)
 				}
 			}
-		case kind404, kindSitemap, kindRobotsTXT:
+		default:
+			pages = p.s.RegularPages()
+		}
+
+		p.regularPages = pages
+
+	})
+
+	return p.regularPages
+}
+
+func (p *pageState) Pages() page.Pages {
+	p.pagesInit.Do(func() {
+		var pages page.Pages
+
+		switch p.Kind() {
+		case page.KindPage:
+		case page.KindSection, page.KindHome:
+			pages = p.getPagesAndSections()
+		case page.KindTaxonomy:
+			termInfo := p.bucket
+			plural := maps.GetString(termInfo.meta, "plural")
+			term := maps.GetString(termInfo.meta, "termKey")
+			taxonomy := p.s.Taxonomies[plural].Get(term)
+			pages = taxonomy.Pages()
+		case page.KindTaxonomyTerm:
+			pages = p.getPagesAndSections()
+		default:
 			pages = p.s.Pages()
 		}
 
@@ -290,11 +329,12 @@ func (p *pageState) getLayoutDescriptor() output.LayoutDescriptor {
 
 		switch p.Kind() {
 		case page.KindSection:
-			section = sections[0]
-		case page.KindTaxonomyTerm:
-			section = p.getTaxonomyNodeInfo().singular
-		case page.KindTaxonomy:
-			section = p.getTaxonomyNodeInfo().parent.singular
+			if len(sections) > 0 {
+				section = sections[0]
+			}
+		case page.KindTaxonomyTerm, page.KindTaxonomy:
+			section = maps.GetString(p.bucket.meta, "singular")
+
 		default:
 		}
 
@@ -355,16 +395,12 @@ func (p *pageState) initPage() error {
 	return nil
 }
 
-func (p *pageState) setPages(pages page.Pages) {
-	page.SortByDefault(pages)
-	p.pages = pages
-}
-
 func (p *pageState) renderResources() (err error) {
 	p.resourcesPublishInit.Do(func() {
 		var toBeDeleted []int
 
 		for i, r := range p.Resources() {
+
 			if _, ok := r.(page.Page); ok {
 				// Pages gets rendered with the owning page but we count them here.
 				p.s.PathSpec.ProcessingStats.Incr(&p.s.PathSpec.ProcessingStats.Pages)
@@ -484,22 +520,7 @@ func (p *pageState) addResources(r ...resource.Resource) {
 	p.resources = append(p.resources, r...)
 }
 
-func (p *pageState) addSectionToParent() {
-	if p.parent == nil {
-		return
-	}
-	p.parent.subSections = append(p.parent.subSections, p)
-}
-
-func (p *pageState) contentMarkupType() string {
-	if p.m.markup != "" {
-		return p.m.markup
-
-	}
-	return p.File().Ext()
-}
-
-func (p *pageState) mapContent(meta *pageMeta) error {
+func (p *pageState) mapContent(bucket *pagesMapBucket, meta *pageMeta) error {
 
 	s := p.shortcodeState
 
@@ -542,7 +563,7 @@ Loop:
 				}
 			}
 
-			if err := meta.setMetadata(p, m); err != nil {
+			if err := meta.setMetadata(bucket, p, m); err != nil {
 				return err
 			}
 
@@ -746,27 +767,6 @@ func (p *pageState) shiftToOutputFormat(isRenderingSite bool, idx int) error {
 	return nil
 }
 
-func (p *pageState) getTaxonomyNodeInfo() *taxonomyNodeInfo {
-	info := p.s.taxonomyNodes.Get(p.SectionsEntries()...)
-
-	if info == nil {
-		// There can be unused content pages for taxonomies (e.g. author that
-		// has not written anything, yet), and these will not have a taxonomy
-		// node created in the assemble taxonomies step.
-		return nil
-	}
-
-	return info
-
-}
-
-func (p *pageState) sortParentSections() {
-	if p.parent == nil {
-		return
-	}
-	page.SortByDefault(p.parent.subSections)
-}
-
 // sourceRef returns the reference used by GetPage and ref/relref shortcodes to refer to
 // this page. It is prefixed with a "/".
 //
@@ -843,6 +843,7 @@ func (ps pageStatePages) findPagePosByFilnamePrefix(prefix string) int {
 
 func (s *Site) sectionsFromFile(fi source.File) []string {
 	dirname := fi.Dir()
+
 	dirname = strings.Trim(dirname, helpers.FilePathSeparator)
 	if dirname == "" {
 		return nil
@@ -850,7 +851,7 @@ func (s *Site) sectionsFromFile(fi source.File) []string {
 	parts := strings.Split(dirname, helpers.FilePathSeparator)
 
 	if fii, ok := fi.(*fileInfo); ok {
-		if fii.bundleTp == bundleLeaf && len(parts) > 0 {
+		if len(parts) > 0 && fii.FileInfo().Meta().Classifier() == files.ContentClassLeaf {
 			// my-section/mybundle/index.md => my-section
 			return parts[:len(parts)-1]
 		}
