@@ -50,6 +50,8 @@ func TestAfter(t *testing.T) {
 		{int64(2), []int{100, 200, 300}, []int{300}},
 		{100, []int{100, 200}, []int{}},
 		{"1", []int{100, 200, 300}, []int{200, 300}},
+		{0, []int{100, 200, 300, 400, 500}, []int{100, 200, 300, 400, 500}},
+		{0, []string{"a", "b", "c", "d", "e"}, []string{"a", "b", "c", "d", "e"}},
 		{int64(-1), []int{100, 200, 300}, false},
 		{"noint", []int{100, 200, 300}, false},
 		{2, []string{}, []string{}},
@@ -493,6 +495,8 @@ func TestLast(t *testing.T) {
 		{int64(2), []int{100, 200, 300}, []int{200, 300}},
 		{100, []int{100, 200}, []int{100, 200}},
 		{"1", []int{100, 200, 300}, []int{300}},
+		{"0", []int{100, 200, 300}, []int{}},
+		{"0", []string{"a", "b", "c"}, []string{}},
 		// errors
 		{int64(-1), []int{100, 200, 300}, false},
 		{"noint", []int{100, 200, 300}, false},
